@@ -8,8 +8,8 @@ objToJSON <- function(obj, file = NULL){
 		obj$normals <- t(obj$normals)
 		faces <- matrix(NA, nrow=nrow(obj$faces), ncol=7)
 		faces[, 1] <- 32
-		faces[, 2:4] <- obj$faces - 1
-		faces[, 5:7] <- obj$faces - 1
+		faces[, 2:4] <- obj$faces[, c(1,3,5)] - 1
+		faces[, 5:7] <- obj$faces[, c(2,4,6)] - 1
 		obj$faces <- t(faces)
 
 		to_json <- toJSON(obj)
