@@ -2,6 +2,9 @@ svg_axis_grids <- function(polygons, grid_by){
 
 	grid <- list()
 	
+	#
+	type <- c()
+	
 	## Create grids
 	for(i in 1:length(polygons)){
 
@@ -13,7 +16,8 @@ svg_axis_grids <- function(polygons, grid_by){
 		x2 <- cbind(seq(polygons[[i]][4, 1], polygons[[i]][3, 1], by=grid_by),
 			seq(polygons[[i]][4, 2], polygons[[i]][3, 2], by=grid_by),
 			seq(polygons[[i]][4, 3], polygons[[i]][3, 3], by=grid_by))
-	
+		
+		type <- c(type, c('out', rep('in', nrow(x1)-2), 'out'))
 		for(j in 1:nrow(x1)) grid[[length(grid)+1]] <- rbind(c(x1[j, ]), c(x2[j, ]))
 
 		# Create grid in other direction
@@ -25,8 +29,9 @@ svg_axis_grids <- function(polygons, grid_by){
 			seq(polygons[[i]][5, 2], polygons[[i]][4, 2], by=grid_by),
 			seq(polygons[[i]][5, 3], polygons[[i]][4, 3], by=grid_by))
 	
+		type <- c(type, c('out', rep('in', nrow(x1)-2), 'out'))
 		for(j in 1:nrow(x1)) grid[[length(grid)+1]] <- rbind(c(x1[j, ]), c(x2[j, ]))
 	}
 	
-	grid
+	list('grid'=grid, 'type'=type)
 }
\ No newline at end of file
